var db =
{
    "#:-S": "#:-S",
    "#-o": "#-o",
    "$-)": "$-)",
    "&": "O",
    "(:|": "(:|",
    "*)": "*)",
    "*-:)": "*-:)",
    ":!!": ":!!",
    ":-\"": ":-\"",
    ":\">": ":\">",
    ":#": ":#",
    ":-#": ":-#",
    ":-$": ":-$",
    ":&": ":&",
    ":-&": ":-&",
    ":(": ":(",
    ":'(": ":'(",
    ":-(": ":-(",
    ":((": ":((",
    ":(:)": ":(:)",
    ":(|)": ":(|)",
    ":)": ":)",
    ":-)": ":-)",
    ":))": ":))",
    ":)]": ":)]",
    ":)~": ":)~",
    ":)>-": ":)>-",
    ":-)>....": ":-)>....",
    ":*": ":*",
    ":-*": ":-*",
    ":\/": ":\/",
    ":-\/": ":-\/",
    ":-?": ":-?",
    ":-??": ":-??",
    ":-@": ":-@",
    ":@)": ":@)",
    ":[": ":[",
    ":\\": ":\\",
    ":]": ":]",
    ":^)": ":^)",
    ":^o": ":^o",
    ":{": ":{",
    ":|": ":|",
    ":}": ":}",
    ":\u00ed(": ":\u00ed(",
    ":<": ":<",
    ":-<": ":-<",
    ":>": ":>",
    ":3": ":3",
    ":-9": ":-9",
    ":ar!": ":ar!",
    ":b": ":b",
    ":-b": ":-b",
    ":-B": ":-B",
    ":-bd": ":-bd",
    ":bz": ":bz",
    ":c": ":c",
    ":-c": ":-c",
    ":c)": ":c)",
    ":D": ":D",
    ":-D": ":-D",
    ":-h": ":-h",
    ":-j": ":-j",
    ":-L": ":-L",
    ":O": ":O",
    ":-O": ":-O",
    ":o)": ":o)",
    ":O)": ":O)",
    ":o3": ":o3",
    ":p": ":p",
    ":-p": ":-p",
    ":P": ":P",
    ":-P": ":-P",
    ":-q": ":-q",
    ":S": ":S",
    ":-S": ":-S",
    ":-SS": ":-SS",
    ":-t": ":-t",
    ":u": ":u",
    ":-w": ":-w",
    ":x": ":x",
    ":X": ":X",
    ":-X": ":-X",
    ";(": ";(",
    ";)": ";)",
    ";-)": ";-)",
    ";))": ";))",
    ";*(": ";*(",
    ";]": ";]",
    ";^)": ";^)",
    ";D": ";D",
    ";o_o;": ";o_o;",
    "@}-;-'---": "@}-;-'---",
    "[:|]": "[:|]",
    "[-O<": "[-O<",
    "[-X": "[-X",
    "\\,,\/": "\\,,\/",
    "\\:D\/": "\\:D\/",
    "\\m\/": "\\m\/",
    "\\o\/": "\\o\/",
    "^#(^": "^#(^",
    "^:)^": "^:)^",
    "~:>": "~:>",
    "~O)": "~O)",
    "~X(": "~X(",
    "<):)": "<):)",
    "<\/3": "<\/3",
    "<:-P": "<:-P",
    "<=3": "<=3",
    "<=8": "<=8",
    "<3": "<3",
    "<333": "<333",
    "=:)": "=:)",
    "=3": "=3",
    "=D": "=D",
    "=D>": "=D>",
    "=p": "=p",
    "=P": "=P",
    "=P~": "=P~",
    ">.<": ">.<",
    ">:(": ">:(",
    ">:-(": ">:-(",
    ">:)": ">:)",
    ">:-)": ">:-)",
    ">:\/": ">:\/",
    ">:D<": ">:D<",
    ">:P": ">:P",
    ">;)": ">;)",
    "0:3": "0:3",
    "0_o": "0_o",
    "0-0": "0-0",
    "0w0": "0w0",
    "10th": "10m",
    "1st": "1m",
    "2nd": "2y",
    "3:-O": "3:-O",
    "3rd": "3y",
    "4th": "4rrth",
    "5th": "5m",
    "6th": "6ShTh",
    "7th": "7m",
    "8)": "8)",
    "8-)": "8-)",
    "8-|": "8-|",
    "8-}": "8-}",
    "8->": "8->",
    "8D": "8D",
    "8O": "8O",
    "8th": "8m",
    "8-X": "8-X",
    "9th": "9m",
    "abdomen": "oZabDOmen",
    "academy": "oZakaDemi",
    "access": "oZaxes",
    "account": "oZakaunT",
    "acer": "esar",
    "acharya": "acarrz",
    "action": "oZakSan",
    "active": "oZakTiv",
    "activity": "oZakTiviTi",
    "adapter": "oZaDapTar",
    "add": "oZaD",
    "aditya": "adity",
    "adjust": "oZaDjasT",
    "adobe": "oZaDOb",
    "adrita": "adrrita",
    "adsense": "aZDsens",
    "advertisement": "oZaDvarrTaijmenT",
    "adwords": "oZaD`OyarrDs",
    "aeroplane": "erOplen",
    "africa": "afrika",
    "aids": "eiDs",
    "aingoto": "ain`goto",
    "ainjIbI": "ain`jIbI",
    "ainkanun": "ain`kanun",
    "ainmafik": "ain`mafik",
    "ainmaphik": "ain`maphik",
    "ainmontrI": "ain`montrI",
    "ainmontroNaloy": "ain`montroNaloy",
    "ainmote": "ain`mote",
    "ainmoto": "ain`moto",
    "ainsocib": "ain`socib",
    "ainsommoto": "ain`sommoto",
    "ainsongoto": "ain`songoto",
    "airport": "eyarpOrrT",
    "airtel": "eyarTel",
    "airway": "ear`we",
    "airways": "ear`wej",
    "akbar": "akbor",
    "akkelguRum": "akkel`guRum",
    "aktel": "ekoTel",
    "alarm": "aZlarrm",
    "album": "oZal`bam",
    "algOch": "al`gOch",
    "almari": "al`mari",
    "alOkmala": "alOk`mala",
    "alOkmoy": "alOk`moy",
    "alOksojja": "alOk`sojja",
    "alOksongket": "alOk`songket",
    "alOkstombho": "alOk`stombho",
    "alOkstomvo": "alOk`stomvo",
    "alphabet": "oZalfabeT",
    "alpin": "al`pin",
    "alt": "olT",
    "amartya": "omorrtyo",
    "america": "amerika",
    "american": "amerikan",
    "amrita": "omrrita",
    "ananda": "anond",
    "anandabajar": "anondobajar",
    "anandabazar": "anondobajar",
    "anatomy": "oZanaTomi",
    "and": "oZanD",
    "andhra": "ondhro",
    "angle": "oZangel",
    "anirban": "onirrbaN",
    "aniruddha": "oniruddho",
    "antenna": "oZanTena",
    "antivirus": "aZnTivairas",
    "anurima": "oNurima",
    "apna": "ap`na",
    "apnaapni": "ap`naap`ni",
    "aponkar": "apon`kar",
    "app": "oZap",
    "apple": "oZapol",
    "application": "oZaplikeSan",
    "apply": "aZplai",
    "april": "epril",
    "arab": "arb",
    "arabia": "arob",
    "archive": "arrkaiv",
    "argentina": "arrjenTina",
    "army": "arrmi",
    "article": "arrTikel",
    "artist": "arrTisT",
    "asbenna": "asben`na",
    "asenni": "asen`ni",
    "ashraful": "ash`raful",
    "asia": "eSia",
    "aslam": "as`lam",
    "asle": "as`le",
    "aslen": "as`len",
    "asli": "as`li",
    "asma": "as`ma",
    "asman": "as`man",
    "asmanI": "as`manI",
    "assistant": "oZasisTyanT",
    "association": "oZasOsiyeSan",
    "atm": "eTiem",
    "audio": "oDiO",
    "auditorium": "oDiTOriam",
    "august": "ogasT",
    "australia": "osTreliya",
    "authority": "othoriTi",
    "auto": "oTO",
    "automatic": "oTOmeTik",
    "automobile": "oTOmObail",
    "autopsy": "oTOpsi",
    "avast": "oZavasT",
    "avenue": "oZavenyu",
    "avro": "ovro",
    "avroo": "ovroO",
    "b-(": "b-(",
    "B(": "B(",
    "B)": "B)",
    "B-)": "B-)",
    "babohar": "bybohar",
    "back": "byak",
    "background": "byakgraunD",
    "backspace": "byak`spes",
    "backup": "byak`ap",
    "badminton": "byaDminTon",
    "baksongzom": "bak`songzom",
    "baksongzomI": "bak`songzomI",
    "baksorrboswo": "bak`sorrboswo",
    "ballot": "byaloT",
    "ballygunge": "baligonj",
    "bamfront": "bam`fronT",
    "bampash": "bam`pash",
    "banasree": "bonSrI",
    "banerjee": "byanarrji",
    "bank": "byangk",
    "baseball": "bes,,bol",
    "basu": "bosu",
    "basundhara": "bosundhora",
    "battery": "byaTari",
    "beat": "biT",
    "begum": "begom",
    "bengal": "bengol",
    "bengali": "bengoli",
    "bharat": "bharot",
    "bhattacharya": "voTTacarrz",
    "bhowmik": "vOUmik",
    "bicycle": "baisaikel",
    "bidyut": "bidyut``",
    "bikkhato": "bikhyato",
    "bill": "bil",
    "biochemistry": "bayOkemisTri",
    "biology": "bayOlji",
    "birla": "biRla",
    "birthday": "barrthDe",
    "bismilla": "bis`milla",
    "bismillah": "bis`millah",
    "bismillahir": "bis`millahir",
    "bit": "biT",
    "blackberry": "blyakberi",
    "bloc": "blok",
    "block": "blok",
    "blogger": "blogar",
    "blouse": "blauj",
    "blue": "blu",
    "bluetooth": "bluTuth",
    "board": "bOrrD",
    "bodmaish": "bod`maish",
    "bodmaishi": "bod`maishi",
    "bodmash": "bod`mash",
    "bodmashi": "bod`mashi",
    "bodmayeshi": "bod`mayeshi",
    "bodmejaj": "bod`mejaj",
    "bodmejajI": "bod`mejajI",
    "bodrag": "bod`rag",
    "bodragI": "bod`ragI",
    "bodrul": "bod`rul",
    "bogra": "boguRa",
    "bolbona": "bol`bona",
    "bolenni": "bolen`ni",
    "bollywood": "boliuD",
    "bonna": "bonya",
    "boolean": "bulian",
    "bosenni": "bosen`ni",
    "botany": "bOTani",
    "brake": "brek",
    "brazil": "brajil",
    "brb": "ekTu pore aschi",
    "break": "brek",
    "britain": "briTen",
    "british": "briTiS",
    "britney": "briTni",
    "broadband": "broDbyanD",
    "browser": "braujar",
    "brush": "brash",
    "bsc": "bi`es`si",
    "btv": "biTivi",
    "buddha": "buddho",
    "buddhadeb": "buddhodeb",
    "building": "bilDing",
    "bulb": "balb",
    "bullet": "buleT",
    "bus": "bas",
    "business": "bijnes",
    "button": "baTon",
    "buzz": "baj",
    "byarrtho": "by`rrtho",
    "byay": "by`Y",
    "byrrth": "by`rrth",
    "byrrthta": "by`rrthta",
    "byrrthtay": "by`rrthtay",
    "byte": "baiT",
    "byy": "by`Y",
    "C:": "C:",
    "cable": "keb,,l",
    "cadre": "kyaDar",
    "cake": "kek",
    "cakladar": "cak`ladar",
    "cakranI": "cak`ranI",
    "cakri": "cak`ri",
    "cakribakri": "cak`ribak`ri",
    "cakri-bakri": "cak`ri-bak`ri",
    "cakrihIn": "cak`rihIn",
    "calculator": "kyal`kuleTor",
    "calcutta": "kyal`kaTa",
    "calendar": "kyalenDar",
    "calkata": "kol`kata",
    "calkumRa": "cal`kumRa",
    "calkumRO": "cal`kumRO",
    "call": "kol",
    "camera": "kyamera",
    "campus": "kyampas",
    "canada": "kanaDa",
    "cancel": "kyan`sel",
    "canon": "kyanon",
    "canvas": "kyanvas",
    "capacity": "kyapasiTi",
    "capgeminee": "kyapjemini",
    "capisna": "capis`na",
    "capisne": "capis`ne",
    "capital": "kyapiTal",
    "caplam": "cap`lam",
    "caple": "cap`le",
    "caplei": "cap`lei",
    "caplen": "cap`len",
    "caplo": "cap`lo",
    "caplO": "cap`lO",
    "caps": "kyap,,s",
    "captam": "cap`tam",
    "capte": "cap`te",
    "capten": "cap`ten",
    "capti": "cap`ti",
    "captis": "cap`tis",
    "capture": "kyapcar",
    "card": "karrD",
    "cargo": "karrgO",
    "carrier": "kyariyar",
    "carry": "kyari",
    "cartoon": "karrTun",
    "cassette": "kyaseT",
    "castro": "kastrO",
    "catalog": "kyaTalog",
    "catalogue": "kyaTalog",
    "cd": "siDi",
    "cell": "sel",
    "cent": "senT",
    "century": "sencuri",
    "certificate": "sarrTifikeT",
    "certification": "sarrTifikeSan",
    "chair": "ceyar",
    "chairman": "ceyarmyan",
    "chalk": "cok",
    "chamber": "cembar",
    "chandan": "condon",
    "channel": "cyanel",
    "character": "kyarekTar",
    "charge": "carrj",
    "charger": "carrjar",
    "chatterjee": "cyaTarrji",
    "checkpost": "cekpOsT",
    "check-post": "cekpOsT",
    "chemical": "kemikyal",
    "chemistry": "kemisTri",
    "chennai": "cennai",
    "chicken": "ciken",
    "china": "cayna",
    "chinese": "cainIj",
    "chittagong": "cTrgram",
    "chokkagoj": "chok`kagoj",
    "chokkaTa": "chok`kaTa",
    "chokkaTO": "chok",
    "chokkaTun": "chok",
    "chrome": "krOm",
    "cikmik": "cik`mik",
    "cikmike": "cik`mike",
    "cimney": "cim`ni",
    "cinema": "sinema",
    "circle": "sarrkel",
    "circular": "sarrkular",
    "circus": "sarrkas",
    "city": "siTi",
    "citycell": "siTisel",
    "civil": "sivil",
    "class": "klas",
    "clear": "kliyar",
    "click": "klik",
    "clip": "klip",
    "clipboard": "klipbOrrD",
    "close": "klOj",
    "close-up": "klOs-ap",
    "club": "klab",
    "cm": "semi.`",
    "coach": "kOc",
    "coal": "kOl",
    "code": "kOD",
    "coin": "koyen",
    "college": "kolej",
    "comilla": "kumilla",
    "comment": "komenT",
    "commerce": "komarrs",
    "commercial": "komarrshial",
    "commission": "komish`n",
    "committee": "komiTi",
    "community": "komiuniTi",
    "compaq": "kom`pyak",
    "complain": "kom`plein",
    "computer": "kompiuTar",
    "computing": "kompiuTing",
    "conductor": "konDakTor",
    "conference": "konfarens",
    "configuration": "konfigareshon",
    "congress": "kong`gres",
    "consortium": "konsorrTiam",
    "control": "konTrOl",
    "convert": "konvarrT",
    "converter": "konvarrTar",
    "cookie": "kuki",
    "copy": "kpi",
    "copyright": "kpiraiT",
    "correct": "karekT",
    "council": "kaunsil",
    "courier": "kZuriyar",
    "court": "kOrrT",
    "courtship": "kOrrTSip",
    "coxsbajar": "koxbajar",
    "cpi": "sipi`ai",
    "cpm": "sipiem",
    "crack": "kryak",
    "cream": "krim",
    "credit": "kreDiT",
    "crest": "kresT",
    "cricket": "krikeT",
    "cricketer": "krikeTar",
    "crime": "kraim",
    "criminal": "kriminal",
    "cross": "kros",
    "crystal": "krisTal",
    "css": "sies`es",
    "cuba": "kiuba",
    "current": "karenT",
    "cursor": "karrsor",
    "custom": "kasTm",
    "cycle": "saikel",
    "d'-'": "d'-'",
    "D:": "D:",
    "d:-)": "d:-)",
    "D:<": "D:<",
    "D-:<": "D-:<",
    "D;": "D;",
    "d'_'": "d'_'",
    "d'_'b": "d'_'b",
    "D<": "D<",
    "D=": "D=",
    "D8": "D8",
    "dairy": "Deyari",
    "darjeeling": "darrjiling",
    "dashboard": "DyaSbOrrD",
    "d'-'b": "d'-'b",
    "dead": "DeD",
    "debbhokti": "deb`bhokti",
    "debbhokto": "deb`bhokto",
    "debit": "DebiT",
    "debug": "Dibag",
    "december": "Disembor",
    "default": "DifolT",
    "define": "Difain",
    "definite": "DefiniT",
    "definitely": "DefineTli",
    "definition": "DefineSan",
    "defragment": "Difryag`menT",
    "defragmenter": "Difryag`menTar",
    "degree": "Digri",
    "delete": "DiliT",
    "delhi": "dilli",
    "delivery": "Delivari",
    "dell": "Del",
    "dentist": "DenTisT",
    "design": "Dijain",
    "designer": "Dijainar",
    "desktop": "DeksTp",
    "detective": "DiTekTiv",
    "developar": "Developar",
    "developer": "Developar",
    "development": "DevelopmenT",
    "device": "Divais",
    "dhaka": "Dhaka",
    "dhUmpan": "dhUm`pan",
    "dhUmpayI": "dhUm`payI",
    "dialog": "Daylog",
    "dialogue": "Daylog",
    "diamond": "DaymonD",
    "diary": "Dayeri",
    "dictionary": "Dik`shonarI",
    "diesel": "Dijel",
    "digicam": "Dijikyam",
    "digit": "DijiT",
    "digital": "DijiTal",
    "dingoto": "din`goto",
    "dinkal": "din`kal",
    "dinman": "din`man",
    "dinmane": "din`mane",
    "dinmojur": "din`mojur",
    "dinner": "Dinar",
    "diplay": "Disople",
    "director": "DirekTor",
    "directx": "DirekT-x",
    "disk": "Disk",
    "display": "Dis`ple",
    "dissection": "DisekSan",
    "dj": "Dije",
    "djuice": "Dijyus",
    "doctor": "Daktar",
    "document": "DokumenT",
    "documents": "DokumenTs",
    "Dogmog": "Dog`mog",
    "dOkandar": "dOkan`dar",
    "dOkandari": "dOkan`dari",
    "dOkla": "dOk`la",
    "dollar": "Dolar",
    "domain": "DOmein",
    "dongle": "Dongol",
    "doshombar": "doshom`bar",
    "doSombar": "doSom`bar",
    "download": "DaunlOD",
    "dr.": "dr.",
    "Dr.": "Dr.",
    "DR.": "DR.",
    "draft": "Draf,,T",
    "drawing": "Droying",
    "dreamweaver": "Drim`wevar",
    "drive": "Draiv",
    "driver": "Draivar",
    "drug": "Drag",
    "dur": "dUr",
    "durga": "durrga",
    "dutch": "Dac",
    "dutt": "dotto",
    "dutta": "dotto",
    "dvd": "DiviDi",
    "DX": "DX",
    "earth": "arrth",
    "east": "isT",
    "easy": "iji",
    "edit": "eDiT",
    "edition": "eDishon",
    "editor": "eDiTor",
    "eid": "Id",
    "einstein": "ainsTain",
    "ekhonkar": "ekhon`kar",
    "ekkal": "ek`kal",
    "ekkalIn": "ek`kalIn",
    "ekkendrIyo": "ek`kendrIyo",
    "ekkotha": "ek`kotha",
    "ekla": "ek`la",
    "ekmatra": "ek`matra",
    "ekmatro": "ek`matro",
    "ekmatrrik": "ek`matrrik",
    "ekmon": "ek`mon",
    "ekmona": "ek`mona",
    "ekmot": "ek`mot",
    "ekmotalombI": "ek`motalombI",
    "ekmukh": "ek`mukh",
    "ekmukhI": "ek`mukhI",
    "ekmukhIkoroN": "ek`mukhIkoroN",
    "ekmukhO": "ek`mukhO",
    "ekrob": "ek`rob",
    "ekrOkha": "ek`rOkha",
    "ekrokom": "ek`rokom",
    "ekrokombhabe": "ek`rokom`bhabe",
    "ekrokomvabe": "ek`rokom`vabe",
    "ekrotti": "ek`rotti",
    "ekrUp": "ek`rUp",
    "eksathe": "ek`sathe",
    "eksonge": "ek`songe",
    "eksthan": "ek`sthan",
    "ekTa": "ek`Ta",
    "ekTaka": "ek`Taka",
    "ektal": "ek`tal",
    "ektala": "ek`tala",
    "ekTana": "ek`Tana",
    "ekTane": "ek`Tane",
    "ekTao": "ek`Tao",
    "ektara": "ek`tara",
    "ekTi": "ek`Ti",
    "ektil": "ek`til",
    "ektola": "ek`tola",
    "ektolay": "ek`tolay",
    "ektomo": "ek`tomo",
    "ektontrI": "ek`tontrI",
    "ektontro": "ek`tontro",
    "ektoro": "ek`toro",
    "ektorofa": "ek`torofa",
    "ektoropha": "ek`toropha",
    "ekTu": "ek`Tu",
    "ekTuk": "ek`Tuk",
    "ekTuku": "ek`Tuku",
    "election": "ilekSan",
    "electric": "ilekTrik",
    "electrical": "ilekTrikyal",
    "electricity": "ilekTrisiTi",
    "electronic": "ilekTronik",
    "electronics": "ilekTroniks",
    "email": "imeil",
    "e-mail": "i-mel",
    "emirates": "emireT,,s",
    "emni": "em`ni",
    "emnikore": "em`nikore",
    "emnitoro": "em`nitoro",
    "emnivabe": "em`nivabe",
    "emonki": "emon`ki",
    "emonTa": "emon`Ta",
    "emonTi": "emon`Ti",
    "emontoro": "emon`toro",
    "empire": "empayar",
    "encoding": "en`kODing",
    "end": "enD",
    "engine": "injin",
    "engineer": "injiniyar",
    "engineering": "injiniyaring",
    "england": "inglyanD",
    "english": "inglish",
    "enrique": "en`rik",
    "enter": "enTar",
    "entrance": "enTrans",
    "entries": "enTrij,,",
    "entry": "enTri",
    "epsiode": "episOD",
    "epson": "ep`son",
    "erricson": "erik`san",
    "etc": "ityadi",
    "etyadi": "ityadi",
    "euro": "iurO",
    "europe": "iurOp",
    "event": "ivenT",
    "everest": "evaresT",
    "excel": "exel",
    "exchange": "xcenj",
    "exercise": "exarsaij",
    "explorer": "explOrar",
    "express": "xpres",
    "extension": "xTensan",
    "fa^ktal": "fa^k`tal",
    "facebook": "feisbuk",
    "fantasy": "fyanTasi",
    "fashion": "fyashan",
    "father": "fadar",
    "fatna": "fat`na",
    "february": "februarI",
    "fedora": "feDOra",
    "feed": "feeD",
    "felbe": "fel`be",
    "felben": "fel`ben",
    "felbi": "fel`bi",
    "felbo": "fel`bo",
    "fellam": "fel`lam",
    "felle": "fel`le",
    "fellen": "fel`len",
    "felleo": "fel`leo",
    "felli": "fel`li",
    "fello": "fel`lo",
    "feynman": "fain`myan",
    "fiction": "fikSan",
    "file": "fail",
    "filter": "filTar",
    "final": "fainal",
    "finance": "fainans",
    "find": "fainD",
    "fine": "fain",
    "finki": "fin`ki",
    "firefox": "fayarfox",
    "firenni": "firen`ni",
    "firewire": "fayar`war",
    "fitna": "fit`na",
    "fixed": "fixD",
    "flash": "flyaS",
    "flickr": "flik,,r",
    "floppy": "flopi",
    "flyover": "flaiOvar",
    "folder": "fOlDar",
    "footage": "fuTej",
    "football": "fuTbol",
    "forensic": "forensik",
    "form": "forrm",
    "format": "formyaT",
    "forum": "fOram",
    "forward": "for`warrD",
    "fossil": "fosil",
    "fossils": "fosil,,s",
    "foundation": "faunDeshon",
    "fountain": "faunTen",
    "france": "frans",
    "freeware": "freeOyZar",
    "friend": "frenD",
    "front": "fronT",
    "frontpage": "fronTpej",
    "fulbabu": "ful`babu",
    "fulbagan": "ful`bagan",
    "fulkopi": "ful`kopi",
    "fund": "fanD",
    "fuslanO": "fus`lanO",
    "fusle": "fus`le",
    "fusliye": "fus`liye",
    "fuzzy": "faji",
    "galgolpo": "gal`golpo",
    "gallery": "gyalari",
    "galmondo": "gal`mondo",
    "game": "gem",
    "gamla": "gam`la",
    "gandhi": "gandhI",
    "ganesh": "goNeS",
    "ganguly": "ganguli",
    "ganI": "gganI",
    "gargi": "garrgI",
    "gariahat": "goRiahaT",
    "gatarrthe": "ggatarrthe",
    "gates": "geT,,s",
    "gautam": "gOUtom",
    "gb": "jibi",
    "generation": "jenareSon",
    "geography": "jiografi",
    "george": "jorrj",
    "german": "jarrman",
    "germany": "jarrmani",
    "ghagra": "ghag`ra",
    "ghapla": "ghap`la",
    "ghora": "ghORa",
    "ghori": "ghoRi",
    "ghosh": "ghOSh",
    "ghumanni": "ghuman`ni",
    "ghurenni": "ghuren`ni",
    "gilTi": "gil`Ti",
    "girl": "garrl",
    "github": "giT`hab",
    "gland": "glyanD",
    "glass": "glas",
    "global": "glObal",
    "globalisation": "glObalaijeSan",
    "globalization": "glObalaijeSan",
    "gmail": "jimeil",
    "gObre": "gOb`re",
    "gogoncarI": "gogon`carI",
    "gogoncor": "gogon`cor",
    "gogoncumbI": "gogon`cumbI",
    "gogonsporrshI": "gogon`sporrshI",
    "gOlgal": "gOl`gal",
    "gOlmal": "gOl`mal",
    "gOlmele": "gOl`mele",
    "gOlmoric": "gOl`moric",
    "gOlpata": "gOl`pata",
    "gomes": "gOmej",
    "good": "gooD",
    "google": "googol",
    "government": "govorrn`menT",
    "grasnalI": "gras`nalI",
    "great": "greT",
    "greece": "grIs",
    "greenland": "grInlyanD",
    "group": "grup",
    "guard": "garrD",
    "gubre": "gub`re",
    "guharoy": "guhoray",
    "guhathakurata": "guhThakurota",
    "guide": "gaiD",
    "gujrat": "guj`rat",
    "gunda": "gunDa",
    "gynaecology": "gainekOloji",
    "ha^Tenni": "ha^Ten`ni",
    "hack": "hyak",
    "haj": "hoj",
    "hall": "hol",
    "hamla": "ham`la",
    "hanger": "hyaNggar",
    "haora": "haORa",
    "haque": "hok",
    "hard": "harrD",
    "harddisk": "harrDoDisk",
    "hardware": "harrD`OyZar",
    "harmonium": "harmOniam",
    "harry": "hyari",
    "hature": "hatuRe",
    "head": "heD",
    "health": "hel,,th",
    "heart": "harrT",
    "heatsink": "hiTsink",
    "hekmot": "hek`mot",
    "hell": "hel",
    "helper": "helpar",
    "hertz": "harrj",
    "hi-fi": "hai-fai",
    "hifi": "haifai",
    "highfive": "haifaiv",
    "history": "hisTri",
    "hitler": "hiTlar",
    "hmm": "hum",
    "hockey": "hoki",
    "hokkotha": "hok`kotha",
    "hollywood": "holiuD",
    "home": "hOm",
    "hostel": "hOsTel",
    "hotel": "hOTel",
    "hotkey": "hoT-ki",
    "howra": "haORa",
    "howrah": "haORa",
    "hp": "eicpi",
    "html": "eicTiem`el",
    "human": "hiumyan",
    "hyderabad": "hayderabad",
    "hydrojen": "haiDrOjen",
    "hype": "haip",
    "I-)": "I-)",
    "ibm": "aibiem",
    "icon": "aikon",
    "idiot": "iDiyoT",
    "ie": "aii",
    "image": "imej",
    "imageready": "imej`reDi",
    "imageshack": "imejSyak",
    "imambaRi": "imam`baRi",
    "imandar": "iman`dar",
    "imandarI": "iman`darI",
    "imranur": "im`ranur",
    "inch": "inci",
    "inches": "inci",
    "include": "inokluD",
    "indhondata": "indhon`data",
    "indhondatrI": "indhon`datrI",
    "india": "inDia",
    "indian": "inDian",
    "indradeep": "indrodIp",
    "info": "infO",
    "information": "inforrmeSon",
    "infrared": "infrareD",
    "injection": "injekshan",
    "input": "inpuT",
    "install": "insTol",
    "institute": "insiTiuT",
    "insurance": "in`siOrens",
    "insure": "insiOr",
    "interface": "inTarfes",
    "international": "inTarnyashonal",
    "internet": "inTarneT",
    "iphone": "aifOn",
    "ipod": "aipoD",
    "ipad": "aipyaD",
    "plus": "plas",
    "iron": "ayron",
    "islam": "is`lam",
    "island": "ailyanD",
    "italy": "iTali",
    "item": "aiTem",
    "itihaslekhok": "itihas`lekhok",
    "jabe": "zabe",
    "jalpaiguri": "jol`paiguRi",
    "jamrul": "jam`rul",
    "janenna": "janen`na",
    "jantam": "jan`tam",
    "jante": "jan`te",
    "janten": "jan`ten",
    "janti": "jan`ti",
    "janto": "jan`to",
    "january": "januarI",
    "je": "ze",
    "jeans": "jin,,s",
    "jedin": "zedin",
    "jehetu": "zehetu",
    "jekhan": "zekhan",
    "jemon": "zemon",
    "jet": "jeT",
    "jholkacche": "jhol`kacche",
    "jholkacchilo": "jhol`kacchilo",
    "jholkani": "jhol`kani",
    "jholkanO": "jhol`kanO",
    "jholmol": "jhol`mol",
    "jholmole": "jhol`mole",
    "jibon": "jIbon",
    "jodi": "zodi",
    "joint": "joyenT",
    "jokhon": "zokhon",
    "jonno": "jonyo",
    "jOsna": "jZOt``sna",
    "josna": "jZOt``sna",
    "jOsnamoy": "jZOt``snamoy",
    "josnamoy": "jZOt``snamoy",
    "jOsnarat": "jZOt``snarat",
    "josnarat": "jZOt``snarat",
    "jOsnaratri": "jZOt``snaratri",
    "josnaratri": "jZOt``snaratri",
    "journalism": "jarrnalijm",
    "journalist": "jarrnalisT",
    "jukti": "zukti",
    "july": "julai",
    "jyoti": "jyOti",
    "jyotirmoy": "jyOtirrmoy",
    "jyatirmoy": "jyOtirrmoy",
    "jyatirmay": "jyOtirrmoy",
    "jZOt``snarater": "jZOt``snarater",
    "kaktal": "kak`tal",
    "kaktalIyo": "kak`talIyo",
    "kalbela": "kal`bela",
    "kalbilombe": "kal`bilombe",
    "kalbilombo": "kal`bilombo",
    "kalbOISakhI": "kal`bOISakhI",
    "kalbOIshakhI": "kal`bOIshakhI",
    "kalbOSekhI": "kal`bOSekhI",
    "kalbOshekhI": "kal`bOshekhI",
    "kalke": "kal`ke",
    "kalkrome": "kal`krome",
    "kalprobahe": "kal`probahe",
    "kalprobaho": "kal`probaho",
    "kalprobhab": "kal`probhab",
    "kalprovab": "kal`provab",
    "kalpuruSh": "kal`puruSh",
    "kalrat": "kal`rat",
    "kalratri": "kal`ratri",
    "kalratrire": "kal`ratrire",
    "kamla": "kam`la",
    "kamra": "kam`ra",
    "kangkhito": "kaNgkkhito",
    "kankaTa": "kan`kaTa",
    "kankhaRa": "kan`khaRa",
    "kankO": "kan`kO",
    "kartik": "karrttik",
    "kasba": "kosba",
    "katrani": "kat`rani",
    "katranO": "kat`ranO",
    "kb": "kebi",
    "key": "kee",
    "keyboard": "kibOrrD",
    "keypad": "kI-pyaD",
    "khanni": "khan`ni",
    "kharagpur": "khoRgpur",
    "khelenni": "khelen`ni",
    "khetre": "kkhetre",
    "khetro": "kkhetro",
    "khetrobisheSh": "kkhetrobisheSh",
    "khetrofol": "kxetrofol",
    "khoda": "khOda",
    "khoma": "kxoma",
    "khoti": "kkhoti",
    "khotibriddhi": "kkhotibrriddhi",
    "khotibrriddhi": "kkhotibrriddhi",
    "khotikor": "kkhotikor",
    "khulbe": "khul`be",
    "khulben": "khul`ben",
    "khulbO": "khul`bO",
    "khullam": "khul`lam",
    "khulle": "khul`le",
    "khullen": "khul`len",
    "khulli": "khul`li",
    "kilbil": "kil`bil",
    "kilbile": "kil`bile",
    "kilo": "kilO",
    "kingdom": "kingDom",
    "kintam": "kin`tam",
    "kinte": "kin`te",
    "kinten": "kin`ten",
    "kinti": "kin`ti",
    "kipTa": "kip`Ta",
    "kipTami": "kip`Tami",
    "kipTamO": "kip`TamO",
    "kisu": "kichu",
    "kisui": "kichui",
    "kitchen": "kicen",
    "km": "kimi.`",
    "kobji": "kob`ji",
    "kolkarkhana": "kol`karkhana",
    "kolkata": "kol`kata",
    "kolkobja": "kol`kobja",
    "kolkol": "kol`kol",
    "kolkollOl": "kol`kollOl",
    "kolkonTh": "kol`konTh",
    "kollaN": "kolyaN",
    "kollaNpur": "kolyaNpur",
    "kolma": "kol`ma",
    "kolombaj": "kolom`baj",
    "kolombajI": "kolom`bajI",
    "kOmolmoti": "kOmol`moti",
    "kompokkhe": "kom`pokkhe",
    "konjuspona": "konjus`pona",
    "konkon": "kon`kon",
    "konkonani": "kon`konani",
    "konkone": "kon`kone",
    "konokmoy": "konok`moy",
    "konokmukuT": "konok`mukuT",
    "konokmukuTe": "konok`mukuTe",
    "kOnTa": "kOn`Ta",
    "kOnTi": "kOn`Ti",
    "korenni": "koren`ni",
    "korrtitto": "korrtrritwo",
    "korrtobbo": "korrtobyo",
    "kosrot": "kos`rot",
    "kosrote": "kos`rote",
    "kosroter": "kos`roter",
    "kosrotI": "kos`rotI",
    "koththo": "kothyo",
    "kotokkhani": "kotok`khani",
    "kotokTa": "kotok`Ta",
    "koyekTa": "koyek`Ta",
    "koyekTi": "koyek`Ti",
    "kukkhato": "kukhyato",
    "kulgorima": "kul`gorima",
    "kulgorrbe": "kul`gorrbe",
    "kulgorrbo": "kul`gorrbo",
    "kulgOUrob": "kul`gOUrob",
    "kulgOUrobe": "kul`gOUrobe",
    "kulguru": "kul`guru",
    "kulkaminI": "kul`kaminI",
    "kulkolonker": "kul`kolonker",
    "kulkolonkI": "kul`kolonkI",
    "kulkolonkinI": "kul`kolonkinI",
    "kulkolonko": "kul`kolonko",
    "kulkonya": "kul`konya",
    "kulkuc": "kul`kuc",
    "kulkuca": "kul`kuca",
    "kulkucO": "kul`kucO",
    "kulkul": "kul`kul",
    "kulTa": "kul`Ta",
    "L-)": "L-)",
    "lab": "lyab",
    "lace": "les",
    "lane": "len",
    "language": "lyanguyej",
    "lansdown": "lyansDaun",
    "laptop": "lyap`Top",
    "lassi": "lacchi",
    "launch": "lonc",
    "lawrence": "lorens",
    "lawyer": "loiyar",
    "layer": "leyar",
    "layout": "le`auT",
    "lbw": "el`biDobliu",
    "lcd": "elsiDi",
    "lecture": "lekcar",
    "legal": "ligal",
    "lenovo": "lenOvO",
    "letter": "leTar",
    "letterhead": "leTarheD",
    "lg": "elji",
    "library": "laibreri",
    "life": "laif",
    "light": "laiT",
    "line": "lain",
    "linkin": "lin,,kin",
    "linux": "linax",
    "live": "laiv",
    "llb": "el.`el.`bi",
    "lobby": "lobi",
    "local": "lOkal",
    "location": "lOkeSan",
    "lock": "lok",
    "logic": "lojik",
    "logical": "lojikal",
    "logo": "lOgO",
    "loklok": "lok`lok",
    "london": "lonDon",
    "lotion": "lOSan,,",
    "lounge": "launj",
    "lunch": "lanc",
    "luxury": "laxari",
    "m.b.b.s": "em.`bi.`bi.`es",
    "mac": "myak",
    "macintosh": "myakin`TOsh",
    "machine": "meSin",
    "macro": "myakrO",
    "maddox": "myaDox",
    "magazine": "myagajin",
    "magistrate": "myajisTreT",
    "maharashtra": "moharaShTr",
    "mahatma": "mhatma",
    "mail": "meil",
    "maitreyee": "mOItreyI",
    "majumdar": "mojumdar",
    "maldah": "maldoh",
    "mall": "mol",
    "mallik": "mollik",
    "mallika": "mollika",
    "mamata": "momota",
    "mamla": "mam`la",
    "mamtaj": "momtaj",
    "management": "myanejmenT",
    "manager": "myanejar",
    "managing": "myanejing",
    "mandela": "myanDela",
    "mangOUrob": "man`gOUrob",
    "manmohan": "mon`mOhon",
    "mansommoto": "man`sommoto",
    "mante": "man`te",
    "manten": "man`ten",
    "manti": "man`ti",
    "manto": "man`to",
    "maradona": "maradOna",
    "march": "marrc",
    "market": "marrkeT",
    "markin": "marrkin",
    "marksbad": "marrk`sbad",
    "marx": "marrks",
    "massenger": "mesenjar",
    "matador": "myaTaDor",
    "maths": "myath,,s",
    "maximize": "myaximaij",
    "maximum": "myaximam",
    "mb": "em`bi",
    "mbbs": "em`bi`bi`es",
    "md.": "emDi.`",
    "mechanic": "mekanik",
    "mechanical": "mekanikyal",
    "mechanism": "mekanijm",
    "media": "miDia",
    "medical": "meDikel",
    "medicine": "meDisin",
    "medinipur": "medinIpur",
    "medium": "miDiam",
    "member": "membar",
    "memory": "memOri",
    "mercedes": "marrsiDij",
    "mess": "mes",
    "message": "mesej",
    "messenger": "mesenjar",
    "metric": "meTrik",
    "mexico": "mexikO",
    "micro": "maikrO",
    "microbiology": "maikrObayOloji",
    "microphone": "maikrOfOn",
    "microscope": "maikrOskOp",
    "microsoft": "maikrOsofT",
    "military": "miliTari",
    "mill": "mil",
    "minimize": "minimaij",
    "minimum": "minimam",
    "minister": "minisTar",
    "minus": "mainas",
    "ml": "mili.`",
    "mm": "mimi.`",
    "mms": "em`em`es",
    "mobile": "mObail",
    "mohot": "mohot``",
    "money": "mani",
    "monitor": "moniTor",
    "mongolbar": "mongol`bar",
    "mongolgIt": "mongol`gIt",
    "mongolgroh": "mongol`groh",
    "mongolgroho": "mongol`groho",
    "mongolia": "mongOlia",
    "mongolkamI": "mongol`kamI",
    "mongolkamona": "mongol`kamona",
    "mongolkarI": "mongol`karI",
    "mongolkariNI": "mongol`kariNI",
    "mongolkor": "mongol`kor",
    "mongolmoy": "mongol`moy",
    "morgue": "morrg",
    "morning": "morrning",
    "mother": "madar",
    "motherboard": "madarbOrrD",
    "motor": "mOTor",
    "motorolla": "moTOrOla",
    "mou": "mOU",
    "mount": "maunT",
    "mouse": "maus",
    "mouth": "mauth",
    "movie": "mubhi",
    "mozilla": "mOjila",
    "mrigoya": "mrrigoya",
    "mrinmoy": "mrrinmoy",
    "ms": "em`es",
    "msn": "em`es`en",
    "muffler": "maf,,lar",
    "mukherjee": "mukharrji",
    "multimedia": "malTimiDia",
    "munmun": "mun`mun",
    "museum": "miujiam",
    "music": "miujik",
    "mutton": "maTn",
    "my": "mai",
    "myanmar": "mayan`mar",
    "mymensingh": "moymonosing`h",
    "myspace": "maispes",
    "nakkan": "nak`kan",
    "nakkaTa": "nak`kaTa",
    "nakkhot": "nak`khot",
    "namaskar": "nomoskar",
    "namenni": "namen`ni",
    "nandigram": "nondIgram",
    "napkin": "nyapkin",
    "narayan": "narayN",
    "national": "nyashonal",
    "native": "neTiv",
    "naxal": "noxal",
    "naxalbari": "noxal`baRi",
    "nazmun": "najmun",
    "negro": "nigrO",
    "net": "neT",
    "network": "neT`warrk",
    "new": "niu",
    "news": "niuj",
    "newspaper": "niujpepar",
    "newyork": "niuiyorrk",
    "next": "nexT",
    "nicobar": "nikObar",
    "nidankal": "nidan`kal",
    "nidankale": "nidan`kale",
    "night": "naiT",
    "nimokharam": "nimok`haram",
    "nimokharami": "nimok`harami",
    "niponwave": "nipon`Oyebh",
    "nobel": "nObel",
    "nobombar": "nobom`bar",
    "nojrana": "noj`rana",
    "nokia": "nOkia",
    "nokri": "nok`ri",
    "nolkUp": "nol`kUp",
    "nonsense": "non,,sens",
    "nOnta": "nOn`ta",
    "norokkunDe": "norok`kunDe",
    "norokkunDo": "norok`kunDo",
    "north": "norrth",
    "norton": "norTn",
    "norway": "nor`we",
    "note": "nOT",
    "notebook": "nOTbuk",
    "notepad": "nOTpyaD",
    "notes": "nOT,,s",
    "notification": "nOTifikeSan",
    "nouka": "nOUka",
    "november": "novembor",
    "noyongOcor": "noyon`gOcor",
    "noyonjol": "noyon`jol",
    "noyonkON": "noyon`kON",
    "noyonmoNi": "noyon`moNi",
    "noyonronjon": "noyon`ronjon",
    "noyonsnigdhokor": "noyon`snigdhokor",
    "noyontara": "noyon`tara",
    "noyontaray": "noyon`taray",
    "ntfs": "en`Ti`ef`es",
    "number": "nambar",
    "numeric": "niumerik",
    "nurse": "narrs",
    "nylon": "nailon",
    "o...o": "o...o",
    "O:)": "O:)",
    "O:-)": "O:-)",
    "o_o": "o_o",
    "O_o": "O_o",
    "O_O": "O_O",
    "o-+": "o-+",
    "o=>": "o=>",
    "o->": "o->",
    "o0o": "o0o",
    "O3O": "O3O",
    "obyrrtho": "oby`rrtho",
    "october": "okTObor",
    "odolbodol": "odol`bodol",
    "offic": "ofis",
    "office": "ofis",
    "officer": "ofisar",
    "ogganjonito": "oggan`jonito",
    "oggankrrito": "oggan`krrito",
    "oggantimir": "oggan`timir",
    "ogotta": "ogotya",
    "Ojondar": "Ojon`dar",
    "ok": "Oke",
    "Ok": "Oke",
    "OK": "Oke",
    "okalbarrdhokyo": "okal`barrdhokyo",
    "okalborrShoN": "okal`borrShoN",
    "okalbrriddho": "okal`brriddho",
    "okalbrriShTi": "okal`brriShTi",
    "Okalotnama": "Okalot`nama",
    "Okalotnamate": "Okalot`namate",
    "Okalotnamay": "Okalot`namay",
    "okaTmUrrkho": "okaT`mUrrkho",
    "okaTTo": "okaTyo",
    "okollaN": "okolyaN",
    "okorrtobbo": "okorrtobyo",
    "okoththo": "okothyo",
    "Olkopi": "Ol`kopi",
    "olokmegh": "olok`megh",
    "OlTanO": "Ol`TanO",
    "olympic": "olimpik",
    "omicronlab": "Omikronlyab",
    "Omicronlab": "Omikronlyab",
    "omlanmukh": "omlan`mukh",
    "omlanmukhe": "omlan`mukhe",
    "Omra": "Om`ra",
    "Omrah": "Om`rah,,",
    "oncolprobhab": "oncol`probhab",
    "oncolprovab": "oncol`provab",
    "onekTa": "onek`Ta",
    "onkontuli": "onkon`tuli",
    "onkontulika": "onkon`tulika",
    "onolborrShI": "onol`borrShI",
    "onolborrShoN": "onol`borrShoN",
    "ononna": "ononya",
    "ononno": "ononyo",
    "onudbayI": "onudwayI",
    "onudbeg": "onudweg",
    "onudbigno": "onudwigno",
    "onujjol": "onujjwol",
    "O-O": "O-O",
    "open": "Open",
    "openoffice": "Open`ofis",
    "operating": "opareTing",
    "operation": "opareSan",
    "opomangrostho": "opoman`grostho",
    "opomanjonok": "opoman`jonok",
    "opomanjonokvabe": "opoman`jonokvabe",
    "opomankor": "opoman`kor",
    "optical": "opTikal",
    "option": "op`shon",
    "options": "op`shon,,s",
    "optionti": "op`shon`Ti",
    "orange": "orenj",
    "original": "orijinal",
    "orkut": "orrkuT",
    "orkutbaj": "orrkuTbaj",
    "orkuting": "orrkuTing",
    "orrthat": "orrthat``",
    "os": "Oes",
    "OS": "Oes",
    "osabdhan": "osab`dhan",
    "osabdhane": "osab`dhane",
    "osabdhanI": "osab`dhanI",
    "osabdhanota": "osab`dhanota",
    "oShTombar": "oShTom`bar",
    "osonkho": "osongkhyo",
    "ostacolgamI": "ostacol`gamI",
    "ostacolgoto": "ostacol`goto",
    "otopor": "ot:por",
    "ounce": "auns",
    "out": "auT",
    "outbox": "auTbox",
    "outline": "auTlain",
    "over": "Obhar",
    "overhead": "OvarheD",
    "ovyasmoto": "ovyas`moto",
    "OwO": "OwO",
    "oxford": "oxfOrrD",
    "oxygen": "oxijen",
    "oyoncolon": "oyon`colon",
    "oyonkal": "oyon`kal",
    "pack": "pyak",
    "paediatric": "peDiaTrik",
    "paediatrics": "peDiaTriks",
    "page": "peij",
    "pagla": "pag`la",
    "paglami": "pag`lami",
    "paglamO": "pag`lamO",
    "paglI": "pag`lI",
    "paint": "peinT",
    "painting": "peinTing",
    "palki": "pal`ki",
    "palki-behara": "pal`ki-behara",
    "palmtop": "pamTp",
    "palokmata": "palok`mata",
    "palokmatar": "palok`matar",
    "palta": "palTa",
    "palTa": "pal`Ta",
    "palTanO": "pal`TanO",
    "palTay": "pal`Tay",
    "palTe": "pal`Te",
    "palTi": "pal`Ti",
    "palTiye": "pal`Tiye",
    "pancayet": "poncayet",
    "panel": "pyanel",
    "panroto": "pan`roto",
    "pant": "pyanT",
    "panty": "pyanTi",
    "pappUNyo": "pap`pUNyo",
    "pargana": "porgoNa",
    "park": "parrk",
    "parker": "parrkar",
    "partha": "parrth",
    "partition": "parrTiSon",
    "party": "parrTi",
    "paShaNmoy": "paShaN`moy",
    "patel": "pyaTel",
    "patent": "peTenT",
    "pathology": "pyatholoji",
    "patrika": "potrika",
    "pause": "poj",
    "pc": "pisi",
    "pencil": "pensil",
    "pentagon": "penTagon",
    "perfume": "parfium",
    "pervez": "parrvej",
    "petro": "peTrO",
    "petrol": "peTrOl",
    "pha^ktal": "pha^k`tal",
    "pharmacology": "farrmakOloji",
    "pharmacy": "farrmesi",
    "phatna": "phat`na",
    "phelbe": "phel`be",
    "phelben": "phel`ben",
    "phelbi": "phel`bi",
    "phelbo": "phel`bo",
    "phellam": "phel`lam",
    "phelle": "phel`le",
    "phellen": "phel`len",
    "phelleo": "phel`leo",
    "phelli": "phel`li",
    "phello": "phel`lo",
    "phinki": "phin`ki",
    "phirenni": "phiren`ni",
    "phitna": "phit`na",
    "phone": "fOn",
    "phonetic": "phoneTik",
    "photo": "phTO",
    "photocopy": "fTOkpi",
    "photoshop": "fTOshop",
    "php": "pieicpi",
    "phulbabu": "phul`babu",
    "phulbabura": "phul`babura",
    "phulbagan": "phul`bagan",
    "phulkopi": "phul`kopi",
    "phuslanO": "phus`lanO",
    "phusle": "phus`le",
    "phusliye": "phus`liye",
    "physics": "fijik,,s",
    "picnic": "piknik",
    "picture": "pikcar",
    "piracy": "pairesi",
    "pirate": "paireT",
    "place": "ples",
    "plane": "plen",
    "plate": "pleT",
    "play": "ple",
    "player": "plear",
    "plug": "plag",
    "point": "poyenT",
    "pOkhraj": "pOkh`raj",
    "police": "puliS",
    "political": "poliTikal",
    "politics": "poliTix",
    "poncombar": "poncom`bar",
    "poRenni": "poRen`ni",
    "porjonto": "porrzonto",
    "poroborti": "poroborrtI",
    "port": "pOrrT",
    "portable": "pOrrTeb`l",
    "portugal": "porrtugal",
    "poScimbongo": "poScim`bongo",
    "poshcimbangla": "poshcim`bangla",
    "poshcimbongo": "poshcim`bongo",
    "poshcimbong": "poshcim`bongo",
    "post": "pOsT",
    "postmortem": "pOsTmorrTem",
    "postpaid": "pOsTpeD",
    "potter": "poTar",
    "pound": "paunD",
    "power": "paOyar",
    "powerpoint": "paOyarpoyenT",
    "prabir": "probIr",
    "pradesh": "prodeS",
    "pranab": "pr`N`b",
    "pratiti": "protIti",
    "pregnancy": "preg`nyansi",
    "pregnant": "preg`nyanT",
    "prepaid": "pripeD",
    "presentation": "prejenTeSan",
    "president": "presiDenT",
    "press": "pres",
    "preview": "priviu",
    "prime": "praim",
    "print": "prinT",
    "printer": "prinTar",
    "prize": "praij",
    "processor": "prosesor",
    "product": "prODakT",
    "production":"prODakshn",
    "professional": "prOfes`nal",
    "professor": "prOfesor",
    "profile": "prOfail",
    "program": "prOgram",
    "programme": "prOgram",
    "programming": "prOgraming",
    "progress": "prOgres",
    "project": "prOjekT",
    "projector": "prOjekTor",
    "prokashman": "prokash`man",
    "prokaSman": "prokaS`man",
    "properties": "proparrTij",
    "property": "proparrTi",
    "prothombar": "prothom`bar",
    "prottasha": "protyasha",
    "prottutponnomoti": "protyut``ponnomoti",
    "proyojon": "proyOjon",
    "proyOjonmafik": "proyOjon`mafik",
    "proyOjonmaphik": "proyOjon`maphik",
    "proyOjonmoto": "proyOjon`moto",
    "publish": "pab`liS",
    "publisher": "pab`liSar",
    "pulse": "pal,,s",
    "qB-)": "qB-)",
    "race": "res",
    "racing": "resing",
    "rack": "ryak",
    "racket": "ryakeT",
    "radio": "reDiO",
    "ragging": "ryaging",
    "rail": "rel",
    "railline": "rel`lain",
    "railway": "rel`we",
    "railways": "rel`wej",
    "rajarshi": "rajorrShi",
    "rajat": "rojot",
    "rajpat": "rajpaT",
    "rakhenni": "rakhen`ni",
    "ranabir": "roNobIr",
    "rape": "rep",
    "rashtrapati": "raShTrpoti",
    "rastrapati": "raShTrpoti",
    "raw": "r'",
    "reader": "riDar",
    "recent": "risenT",
    "reception": "risepSan",
    "receptionist": "risepSanisT",
    "recipe": "resipi",
    "recycle": "risaikel",
    "referee": "refaree",
    "refresh": "rifreS",
    "register": "rejisTar",
    "registration": "rejisTreSan",
    "relgaRi": "rel`gaRi",
    "reliance": "rilayens",
    "rellain": "rel`lain",
    "relpoth": "rel`poth",
    "relpothe": "rel`pothe",
    "relpother": "rel`pother",
    "remote": "rimOT",
    "remove": "rimuv",
    "repair": "ripeyar",
    "replace": "riples",
    "resize": "risaij",
    "resolution": "rejOliuSan",
    "restaurant": "resTurenT",
    "rhombus": "rombos",
    "richard": "ricarrD",
    "right": "raiT",
    "rights": "raiT,,s",
    "ringtone": "ringTOn",
    "rituparna": "rrituporrNa",
    "rizwanur": "rij`wanur",
    "rObbar": "rOb`bar",
    "robot": "rOboT",
    "rodon": "rOdon",
    "rOgmukti": "rOg`mukti",
    "rOgmukto": "rOg`mukto",
    "rohman": "roh`man",
    "ronaldinho": "rOnalDinhO",
    "ronaldo": "rOnalDO",
    "rong": "roNg",
    "ronger": "roNger",
    "route": "ruT",
    "row": "rO",
    "rriNgrahI": "rriN`grahI",
    "rriNgrohIta": "rriN`grohIta",
    "rriNgrohoN": "rriN`grohoN",
    "rriNgrostho": "rriN`grostho",
    "rriNmOcon": "rriN`mOcon",
    "rriNmukti": "rriN`mukti",
    "rriNmukto": "rriN`mukto",
    "rss": "ar.`es.`es",
    "RSS": "ar.`es.`es",
    "rubber": "rabar",
    "rugby": "ragbi",
    "rumpa": "rUmpa",
    "rupam": "rUpom",
    "russia": "raSia",
    "sabdhan": "sab`dhan",
    "sabdhanI": "sab`dhanI",
    "sabdhanota": "sab`dhanota",
    "sabyasaci": "sobysacI",
    "saint": "senT",
    "saltlake": "solTlek",
    "samla": "sam`la",
    "samlan": "sam`lan",
    "samlanO": "sam`lanO",
    "samlao": "sam`lao",
    "samna": "sam`na",
    "samnasamni": "sam`nasam`ni",
    "samna-samni": "sam`na-sam`ni",
    "samne": "sam`ne",
    "samni": "sam`ni",
    "samsung": "syamsaNg",
    "sanitary": "syaniTari",
    "sanjana": "sonjona",
    "saptarshi": "soptorrShi",
    "saraswati": "soroswtI",
    "saswata": "SaSwot",
    "satej": "sotej",
    "sauce": "sos",
    "saudi": "sOUdi",
    "saurav": "sOUrobh",
    "save": "sev",
    "scanner": "skyanar",
    "scholar": "skolar",
    "school": "skul",
    "science": "sayens",
    "scooter": "skuTar",
    "scotch": "skoc",
    "scotland": "skoTlyanD",
    "scrap": "skryap",
    "screen": "skreen",
    "scroll": "skrol",
    "scrollbar": "skrol`bar",
    "sealda": "Sialda",
    "sealdah": "Sialdoh",
    "search": "sarrc",
    "sekhetre": "sekkhetre",
    "select": "silekT",
    "semi-final": "semi-fainal",
    "sengupta": "sen`gupt",
    "september": "sepTembor",
    "serial": "sirial",
    "series": "sirij",
    "service": "sarrvis",
    "services": "sarrvises",
    "session": "seSan",
    "set": "seT",
    "setting": "seTing",
    "settings": "seTings,,",
    "sexy": "sexi",
    "shampoo": "shyampu",
    "shanghai": "sang`hai",
    "shankar": "Sonkor",
    "shantiniketan": "Santiniketon",
    "shapla": "shap`la",
    "sharatchandra": "Sorot``condro",
    "share": "sheyar",
    "sharma": "Sorrma",
    "shift": "shifT",
    "shirt": "sharrT",
    "shobdaho": "shob`daho",
    "shobdahok": "shob`dahok",
    "shobdahon": "shob`dahon",
    "shobdeho": "shob`deho",
    "shock": "Sk",
    "shocker": "Skar",
    "shoe": "Su",
    "ShOloana": "ShOlo`ana",
    "shOnni": "shOn`ni",
    "shopping": "Soping",
    "shorot": "shorot``",
    "shortcut": "SorrTkaT",
    "shounak": "SOUnok",
    "show": "SO",
    "shreyasee": "SreysI",
    "shreyasi": "SreysI",
    "shunno": "shunyo",
    "shunnota": "shunyota",
    "shuntam": "shun`tam",
    "shunte": "shun`te",
    "shunten": "shun`ten",
    "shunti": "shun`ti",
    "siddhartha": "siddharrth",
    "siemens": "simens",
    "sign": "sain",
    "signature": "sig`necar",
    "siliguri": "SiliguRi",
    "sIlmOhor": "sIl`mOhor",
    "simanto": "sImant",
    "singapore": "singapur",
    "singh": "sing`h",
    "sir": "syar",
    "site": "saiT",
    "size": "saij",
    "skirt": "skarrT",
    "slide": "slaiD",
    "small": "smol",
    "smart": "smarrT",
    "sms": "es`em`es",
    "Sobdaho": "Sob`daho",
    "Sobdahok": "Sob`dahok",
    "Sobdahon": "Sob`dahon",
    "Sobdeho": "Sob`deho",
    "sobji": "sob`ji",
    "sobkhetre": "sobkxetre",
    "sobkhetro": "sobkxetro",
    "soft": "sofT",
    "software": "sofT`OyZar",
    "soldier": "sOljar",
    "somadhanTi": "somadhan`Ti",
    "somak": "sOmok",
    "sOmbar": "sOm`bar",
    "somen": "sOmen",
    "sommanjonok": "somman`jonok",
    "sommankor": "somman`kor",
    "somrat": "somraT",
    "sonali": "sOnali",
    "sonar": "sOnar",
    "sondha": "sondhya",
    "sondhamaloti": "sondhyamaloti",
    "SOnni": "SOn`ni",
    "sony": "soni",
    "soptombar": "soptom`bar",
    "sot": "sot``",
    "sotti": "sotyi",
    "sotto": "sotyo",
    "soumya": "sOUmyo",
    "soumyajyoti": "sOUmyjyOti",
    "sound": "saunD",
    "source": "sOrrs",
    "south": "sauth",
    "space": "spes",
    "speaker": "spikar",
    "spider": "spaiDar",
    "sports": "spOrrTs",
    "spy": "spai",
    "spycam": "spaikyam",
    "spyware": "spaiOyZar",
    "square": "skOyar",
    "sri": "shrI",
    "srijani": "SrIjonI",
    "srikanta": "SrIkant",
    "srilanka": "SrIlonka",
    "sriman": "shrIman",
    "srimati": "shrImti",
    "srizon": "srrijon",
    "stamp": "sTyamp",
    "stand": "sTyanD",
    "standard": "sTZanDarrD",
    "star": "sTar",
    "start": "sTarrT",
    "states": "sTeT,,s",
    "status": "sTyaTas",
    "steam": "sTim",
    "steering": "sTiaring",
    "sthankalpatro": "sthan`kal`patro",
    "stick": "sTik",
    "stock": "sTk",
    "stool": "sTul",
    "street": "sTriT",
    "string": "sTring",
    "stupid": "sTupiD",
    "style": "sTail",
    "subarna": "suborrNa",
    "subhodip": "shuvodIp",
    "subject": "sab`jekT",
    "suchitra": "sucitra",
    "sudoku": "suDOku",
    "suitcase": "suTkes",
    "suite": "sZuT",
    "suman": "sumon",
    "sumana": "sumona",
    "superman": "suparmyan",
    "support": "sapOrrT",
    "surf": "sarrf",
    "surgery": "sarrjari",
    "swarnendu": "sworrnendu",
    "sweater": "sOyeTar",
    "sweety": "suiTi",
    "swiss": "suis",
    "switch": "suic",
    "sydney": "siDni",
    "syria": "siria",
    "system": "sisTem",
    "T.T": "T.T",
    "T_T": "T_T",
    "tab": "Tyab",
    "tabla": "tob`la",
    "table": "Tebil",
    "tagore": "TegOr",
    "tajmahal": "tajmohol",
    "Takri": "Tak`ri",
    "Talbahana": "Tal`bahana",
    "talgach": "tal`gach",
    "talk": "Tk",
    "talkana": "tal`kana",
    "talmafik": "tal`mafik",
    "talmaphik": "tal`maphik",
    "TalmaTal": "Tal`maTal",
    "talmoto": "tal`moto",
    "talpata": "tal`pata",
    "talpatar": "tal`patar",
    "talpatay": "tal`patay",
    "talpotre": "tal`potre",
    "talpotrer": "tal`potrer",
    "talpotro": "tal`potro",
    "tamali": "tomali",
    "tank": "Tyank",
    "tarzan": "Tarjan",
    "task": "Task",
    "taskbar": "Taskbar",
    "tata": "TaTa",
    "tax": "Tyax",
    "taxi": "Tyaxi",
    "team": "Tim",
    "tech": "Tek",
    "technician": "TekniSian",
    "technology": "TeknOlji",
    "techpointer": "TekpoyenTar",
    "telephone": "TeliphOn",
    "telescope": "TeliskOp",
    "teletalk": "TeliTk",
    "television": "TeliviSan",
    "temni": "tem`ni",
    "temnibhabe": "tem`nibhabe",
    "temnikore": "tem`nikore",
    "temnivabe": "tem`nivabe",
    "temporary": "TempOrari",
    "tennis": "Tenis",
    "testimonial": "TesTimOniyal",
    "text": "TexT",
    "textmate": "TexT`meT",
    "textbox": "TexTbox",
    "textile": "TexTail",
    "tft": "TiefTi",
    "thakenni": "thaken`ni",
    "thaklam": "thak`lam",
    "thakle": "thak`le",
    "thaklo": "thak`lo",
    "Thakrun": "Thak`run",
    "thaktam": "thak`tam",
    "thakte": "thak`te",
    "thakten": "thak`ten",
    "thakti": "thak`ti",
    "thakur": "Thakur",
    "Thandi": "Than`di",
    "Thandidi": "Than`didi",
    "theater": "thiyeTar",
    "Thikmoto": "Thik`moto",
    "ThikThik": "Thik`Thik",
    "ThonThon": "Thon`Thon",
    "ThonThone": "Thon`Thone",
    "threat": "threT",
    "TikTik": "Tik`Tik",
    "TikTiki": "Tik`Tiki",
    "tilottoma": "tilOttoma",
    "time": "Taim",
    "times": "Taim,,s",
    "tingun": "tin`gun",
    "tinjon": "tin`jon",
    "tinjona": "tin`jona",
    "tinkal": "tin`kal",
    "tinrokom": "tin`rokom",
    "tinTa": "tin`Ta",
    "tinTaka": "tin`Taka",
    "tinTane": "tin`Tane",
    "tinTanei": "tin`Tanei",
    "tinTi": "tin`Ti",
    "tintin": "Tin`Tin",
    "Tips": "Tip`s",
    "Tipsohi": "Tip`sohi",
    "Tipsoi": "Tip`soi",
    "TipTip": "Tip`Tip",
    "titanic": "TaiTanik",
    "tobla": "tob`la",
    "tohfa": "tOhfa",
    "toirI": "tOIrI",
    "tokhonkar": "tokhon`kar",
    "toklif": "tok`lif",
    "tokliph": "tok`liph",
    "tokma": "tok`ma",
    "toktok": "tok`tok",
    "TokTok": "Tok`Tok",
    "toktoke": "tok`toke",
    "tokyo": "TOkiyO",
    "tollygunge": "Taligonj",
    "Tolmol": "Tol`mol",
    "tolpeT": "tol`peT",
    "TolTol": "Tol`Tol",
    "TolTole": "Tol`Tole",
    "tomato": "TomeTO",
    "tOmra": "tOm`ra",
    "tOmrai": "tOm`rai",
    "tOmrao": "tOm`rao",
    "tOmratO": "tOm`ratO",
    "tonic": "Tnik",
    "TonTon": "Ton`Ton",
    "TonTonani": "Ton`Tonani",
    "TonTone": "Ton`Tone",
    "tool": "Tool",
    "toolbar": "Tul`bar",
    "tools": "Tuls",
    "torolbuddhi": "torol`buddhi",
    "torolmoti": "torol`moti",
    "torolprokrriti": "torol`prokrriti",
    "torrent": "TorenT",
    "TosTos": "Tos`Tos",
    "TosTosa": "Tos`Tosa",
    "TosTose": "Tos`Tose",
    "total": "TOTal",
    "touchpad": "TacpyaD",
    "touchscreen": "TacskrIn",
    "toufik": "tOUfik",
    "tourism": "Tyurij,,m",
    "tourist": "TyurisT",
    "town": "Taun",
    "tower": "TaoYar",
    "toyota": "ToyOTa",
    "tractor": "TryakTor",
    "trademark": "TreDmarrk",
    "traffic": "Trafik",
    "train": "Tren",
    "trapezium": "Trapijiam",
    "tray": "Tre",
    "trinamul": "trriNomUl",
    "trouser": "Traujar",
    "truck": "Trak",
    "tsunami": "sunami",
    "TT_TT": "TT_TT",
    "tube": "Tiub",
    "tubelight": "Tiub`laiT",
    "Tukra": "Tuk`ra",
    "TukragulO": "Tuk`ragulO",
    "TukraTa": "Tuk`raTa",
    "TukraTakra": "Tuk`raTak`ra",
    "Tukra-Takra": "Tuk`ra-Tak`ra",
    "TukraTi": "Tuk`raTi",
    "Tukri": "Tuk`ri",
    "Tukrite": "Tuk`rite",
    "TukTak": "Tuk`Tak",
    "TukTuke": "Tuk`Tuke",
    "tumpa": "Tumpa",
    "TunTun": "Tun`Tun",
    "TunTuni": "Tun`Tuni",
    "TusTus": "Tus`Tus",
    "TusTusa": "Tus`Tusa",
    "TusTuse": "Tus`Tuse",
    "tv": "Tivi",
    "twitter": "TuiTar",
    "type": "Taip",
    "typing": "Taiping",
    "tyre": "Tayar",
    "uae": "iuei",
    "udbayI": "udwayI",
    "udbek": "udwek",
    "udbigno": "udwigno",
    "uddOg": "udyOg",
    "ujjol": "ujjwol",
    "ulTa": "ul`Ta",
    "ulTanO": "ul`TanO",
    "ulTapalTa": "ul`Tapal`Ta",
    "ulTapiTh": "ul`TapiTh",
    "ulTapiThe": "ul`TapiThe",
    "ulTaroth": "ul`Taroth",
    "ulTarothe": "ul`Tarothe",
    "ulTe": "ul`Te",
    "ulTO": "ul`TO",
    "ulTOpoth": "ul`TOpoth",
    "ulTOroth": "ul`TOroth",
    "under": "anDar",
    "underpant": "anDarpyanT",
    "unibijoy": "iunibijoy",
    "unicode": "iunikOD",
    "uninstall": "an`insTl",
    "union": "iuniyon",
    "unit": "iuniT",
    "united": "iunaiTeD",
    "university": "iunivarrsiTi",
    "update": "apDeT",
    "uponyaskar": "uponyas`kar",
    "uponyaslekhok": "uponyas`lekhok",
    "uponyasrocoyita": "uponyas`rocoyita",
    "ups": "iupies",
    "urine": "iurin",
    "uRonconDI": "uRon`conDI",
    "usb": "iuesbi",
    "user": "iujar",
    "uShno": "uShNo",
    "uThenni": "uThen`ni",
    "utkoT": "ut``koT",
    "utrai": "ut`rai",
    "utralam": "ut`ralam",
    "utralen": "ut`ralen",
    "utrali": "ut`rali",
    "utralO": "ut`ralO",
    "utranO": "ut`ranO",
    "utse": "ut``se",
    "utser": "ut``ser",
    "utso": "ut``so",
    "uttamkumar": "uttomkumar",
    "v.v": "v.v",
    "valobastam": "valobas`tam",
    "valobaste": "valobas`te",
    "valobasten": "valobas`ten",
    "valobasti": "valobas`ti",
    "valobasto": "valobas`to",
    "vasha": "vaSha",
    "version": "varrson",
    "victoria": "vikTOriya",
    "video": "viDio",
    "view": "viu",
    "violin": "vayOlin",
    "virtual": "varrcuyal",
    "vodafone": "vODafOn",
    "volume": "volium",
    "voumik": "vOUmik",
    "wait": "weT",
    "wallpaper": "wal`pepar",
    "warming": "warrming",
    "warning": "warrning",
    "webcam": "Oyebkyam",
    "webmaster": "webmasTar",
    "webpage": "Oyebpej",
    "website": "websaiT",
    "weight": "weT",
    "wellington": "welingTon",
    "west": "wesT",
    "wheel": "huil",
    "whisky": "huiski",
    "wifi": "waifai",
    "wiki": "uiki",
    "wikipedia": "uikipeDia",
    "winamp": "uinaZmp",
    "window": "uinDO",
    "windows": "uinDOj",
    "windscreen": "uinDskrIn",
    "wine": "wain",
    "wipro": "uiprO",
    "wireless": "warles",
    "with": "uith",
    "word": "OarrD",
    "wordpad": "OarrDpyaD",
    "wordpress": "warrDpres",
    "world": "warrlD",
    "wow": "waw",
    "writer": "raiTar",
    "x-(": "x-(",
    "X(": "X(",
    "X_X": "X_X",
    "X3": "X3",
    "xD": "xD",
    "XD": "XD",
    "xerox": "jerox",
    "xhtml": "x`eicTiem`el",
    "xml": "x`em`el",
    "xcode": "xkOD",
    "xp": "xpi",
    "yard": "yarrD",
    "year": "iyar",
    "youtube": "iuTiub",
    "zaman": "jaman",
    "zanni": "zan`ni",
    "zemni": "zem`ni",
    "zemnibhabe": "zem`nibhabe",
    "zemnikore": "zem`nikore",
    "zemnivabe": "zem`nivabe",
    "zia": "jia",
    "zitu": "jitu",
    "zOgandar": "zOgan`dar",
    "zOgandarI": "zOgan`darI",
    "zokhonkar": "zokhon`kar",
    "zokhontokhon": "zokhon`tokhon",
    "zompUrI": "zom`pUrI"
}
